Exception: LabelZoom::Error
- Inherits:
-
StandardError
- Object
- StandardError
- LabelZoom::Error
- Defined in:
- lib/labelzoom/errors.rb
Overview
Base class for everything this gem raises on its own behalf.
Base class for everything this gem raises on its own behalf.